@@ -18,6 +18,7 @@
 # the LICENSES folder.
 
 # This module uses Tikhonov regularization and either radial basis function or piecewise linear discretization
+# 10.1016/j.electacta.2015.09.097
 # pyDRTtools commit: 65ea54d9332a0c6594de852f0242a88e20ec4427
 
 from multiprocessing import (
@@ -79,10 +80,25 @@ from scipy.linalg import (
 from scipy.optimize import (
     fsolve,
 )
-from cvxopt import (
-    matrix,
-    solvers as cvxopt_solvers,
-)
+
+IMPORTED_CONVEX_OPTIMIZER: bool = False
+try:
+    from kvxopt import (
+        matrix,
+        solvers as cvxopt_solvers,
+    )
+
+    IMPORTED_CONVEX_OPTIMIZER = True
+except ImportError:
+    try:
+        from cvxopt import (
+            matrix,
+            solvers as cvxopt_solvers,
+        )
+
+        IMPORTED_CONVEX_OPTIMIZER = True
+    except ImportError:
+        pass
 
 try:
     from cvxpy import (
@@ -91,8 +107,11 @@ try:
         Variable,
         quad_form,
     )
+
+    IMPORTED_CONVEX_OPTIMIZER = True
 except ImportError:
     pass
+
 from pyimpspec.data import DataSet
 from pyimpspec.analysis.fitting import _calculate_residuals
 from .result import (
@@ -1180,6 +1199,9 @@ def _calculate_drt_tr_rbf(
     maximum_symmetry: float = 0.3,
     num_procs: int = -1,
 ) -> DRTResult:
+    assert (
+        IMPORTED_CONVEX_OPTIMIZER is True
+    ), "Failed to import any convex optimizers! At least one of the following packages is required: cvxopt, cvxpy, or kvxopt."
     assert type(mode) is str and mode in MODES, f"Valid mode values: {', '.join(MODES)}"
     assert issubdtype(type(lambda_value), floating), lambda_value
     assert (
@@ -1238,6 +1260,7 @@ def _calculate_drt_tr_rbf(
     progress.update_every_N_percent(0, total=3, message=progress_message)
     A_re: ndarray
     A_im: ndarray
+    i: int
     with Pool(2 if num_procs > 1 else 1) as pool:
         for i, res in enumerate(
             pool.imap(
@@ -1302,7 +1325,6 @@ def _calculate_drt_tr_rbf(
         ] = []
         progress_message = "Calculating DRT"
         progress.update_every_N_percent(0, message=progress_message)
-        i: int
         for i, res in enumerate(pool.imap_unordered(_lambda_process, args)):
             progress.update_every_N_percent(
                 i + 1,
